@@ -10,10 +10,10 @@ import (
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
-	"github.com/golangci/golangci-lint/pkg/config"
-	"github.com/golangci/golangci-lint/pkg/logutils"
-	"github.com/golangci/golangci-lint/pkg/report"
-	"github.com/golangci/golangci-lint/pkg/result"
+	"github.com/golangci/golangci-lint/v2/pkg/config"
+	"github.com/golangci/golangci-lint/v2/pkg/logutils"
+	"github.com/golangci/golangci-lint/v2/pkg/report"
+	"github.com/golangci/golangci-lint/v2/pkg/result"
 )
 
 func unmarshalFile(t *testing.T, filename string, v any) {
@@ -29,7 +29,7 @@ func unmarshalFile(t *testing.T, filename string, v any) {
 func TestPrinter_Print_stdout(t *testing.T) {
 	logger := logutils.NewStderrLog("skip")
 
-	var issues []result.Issue
+	var issues []*result.Issue
 	unmarshalFile(t, "in-issues.json", &issues)
 
 	data := &report.Data{}
@@ -37,25 +37,20 @@ func TestPrinter_Print_stdout(t *testing.T) {
 
 	testCases := []struct {
 		desc     string
-		cfg      *config.Output
+		cfg      *config.Formats
 		expected string
 	}{
 		{
-			desc: "stdout (implicit)",
-			cfg: &config.Output{
-				Formats: []config.OutputFormat{
-					{Format: "line-number"},
-				},
-			},
+			desc:     "stdout (implicit)",
+			cfg:      &config.Formats{},
 			expected: "golden-line-number.txt",
 		},
 		{
 			desc: "stdout (explicit)",
-			cfg: &config.Output{
-				Formats: []config.OutputFormat{
-					{
-						Format: "line-number",
-						Path:   "stdout",
+			cfg: &config.Formats{
+				Text: config.Text{
+					SimpleFormat: config.SimpleFormat{
+						Path: "stdout",
 					},
 				},
 			},
@@ -67,7 +62,7 @@ func TestPrinter_Print_stdout(t *testing.T) {
 		t.Run(test.desc, func(t *testing.T) {
 			t.Parallel()
 
-			p, err := NewPrinter(logger, test.cfg, data)
+			p, err := NewPrinter(logger, test.cfg, data, "")
 			require.NoError(t, err)
 
 			var stdOutBuffer bytes.Buffer
@@ -91,22 +86,21 @@ func TestPrinter_Print_stdout(t *testing.T) {
 func TestPrinter_Print_stderr(t *testing.T) {
 	logger := logutils.NewStderrLog("skip")
 
-	var issues []result.Issue
+	var issues []*result.Issue
 	unmarshalFile(t, "in-issues.json", &issues)
 
 	data := &report.Data{}
 	unmarshalFile(t, "in-report-data.json", data)
 
-	cfg := &config.Output{
-		Formats: []config.OutputFormat{
-			{
-				Format: "line-number",
-				Path:   "stderr",
+	cfg := &config.Formats{
+		Text: config.Text{
+			SimpleFormat: config.SimpleFormat{
+				Path: "stderr",
 			},
 		},
 	}
 
-	p, err := NewPrinter(logger, cfg, data)
+	p, err := NewPrinter(logger, cfg, data, "")
 	require.NoError(t, err)
 
 	var stdOutBuffer bytes.Buffer
@@ -128,7 +122,7 @@ func TestPrinter_Print_stderr(t *testing.T) {
 func TestPrinter_Print_file(t *testing.T) {
 	logger := logutils.NewStderrLog("skip")
 
-	var issues []result.Issue
+	var issues []*result.Issue
 	unmarshalFile(t, "in-issues.json", &issues)
 
 	data := &report.Data{}
@@ -136,16 +130,15 @@ func TestPrinter_Print_file(t *testing.T) {
 
 	outputPath := filepath.Join(t.TempDir(), "report.txt")
 
-	cfg := &config.Output{
-		Formats: []config.OutputFormat{
-			{
-				Format: "line-number",
-				Path:   outputPath,
+	cfg := &config.Formats{
+		Text: config.Text{
+			SimpleFormat: config.SimpleFormat{
+				Path: outputPath,
 			},
 		},
 	}
 
-	p, err := NewPrinter(logger, cfg, data)
+	p, err := NewPrinter(logger, cfg, data, "")
 	require.NoError(t, err)
 
 	var stdOutBuffer bytes.Buffer
@@ -172,7 +165,7 @@ func TestPrinter_Print_file(t *testing.T) {
 func TestPrinter_Print_multiple(t *testing.T) {
 	logger := logutils.NewStderrLog("skip")
 
-	var issues []result.Issue
+	var issues []*result.Issue
 	unmarshalFile(t, "in-issues.json", &issues)
 
 	data := &report.Data{}
@@ -180,24 +173,21 @@ func TestPrinter_Print_multiple(t *testing.T) {
 
 	outputPath := filepath.Join(t.TempDir(), "teamcity.txt")
 
-	cfg := &config.Output{
-		Formats: []config.OutputFormat{
-			{
-				Format: "teamcity",
-				Path:   outputPath,
-			},
-			{
-				Format: "json",
-				Path:   "",
-			},
-			{
-				Format: "line-number",
-				Path:   "stderr",
+	cfg := &config.Formats{
+		TeamCity: config.SimpleFormat{
+			Path: outputPath,
+		},
+		JSON: config.SimpleFormat{
+			Path: "stdout",
+		},
+		Text: config.Text{
+			SimpleFormat: config.SimpleFormat{
+				Path: "stderr",
 			},
 		},
 	}
 
-	p, err := NewPrinter(logger, cfg, data)
+	p, err := NewPrinter(logger, cfg, data, "")
 	require.NoError(t, err)
 
 	var stdOutBuffer bytes.Buffer
@@ -225,5 +215,5 @@ func TestPrinter_Print_multiple(t *testing.T) {
 	goldenJSON, err := os.ReadFile(filepath.Join("testdata", "golden-json.json"))
 	require.NoError(t, err)
 
-	assert.Equal(t, string(goldenJSON), stdOutBuffer.String())
+	assert.JSONEq(t, string(goldenJSON), stdOutBuffer.String())
 }
