@@ -6,15 +6,31 @@ import (
 	"path/filepath"
 )
 
-func copyChangelog(dir string) error {
-	marker := "<!-- START --->"
+func copyChangelogs(dir string) error {
+	data := map[string]string{
+		"CHANGELOG.md":    filepath.Join(dir, "raw_changelog.tmp"),
+		"CHANGELOG-v1.md": filepath.Join(dir, "raw_changelog_v1.tmp"),
+	}
 
-	in, err := os.ReadFile("CHANGELOG.md")
+	for src, dst := range data {
+		err := copyChangelog(src, dst)
+		if err != nil {
+			return err
+		}
+	}
+
+	return nil
+}
+
+func copyChangelog(src, dst string) error {
+	markerStart := "<!-- START --->"
+
+	in, err := os.ReadFile(src)
 	if err != nil {
 		return err
 	}
 
-	out, err := os.Create(filepath.Join(dir, "raw_changelog.tmp"))
+	out, err := os.Create(dst)
 	if err != nil {
 		return err
 	}
@@ -24,7 +40,7 @@ func copyChangelog(dir string) error {
 	var write bool
 
 	for line := range bytes.Lines(bytes.ReplaceAll(in, []byte("### "), []byte("## "))) {
-		if bytes.Equal(bytes.TrimSpace(line), []byte(marker)) {
+		if bytes.Equal(bytes.TrimSpace(line), []byte(markerStart)) {
 			write = true
 			continue
 		}
